BarMarker

Enum BarMarker 

pub enum BarMarker {
    NotRunning,
    CountIn(u16),
    Number(u16),
    RunningUnknown,
}
Indicates that the next MIDI clock message is the first clock of a new measure. Which bar is optionally indicated by this message. Used by UniversalRealTimeMsg::BarMarker.

Variants



NotRunning

“Actually, we’re not running right now, so there is no bar.” Don’t know why this is used.



CountIn(u16)

The bar is a count-in and are thus negative numbers from 8191-0.



Number(u16)

A regular bar numbered 1-8191.



RunningUnknown

Next clock message will be a new bar, but it’s not known what its number is.