Division

Enum Division 

pub enum Division {
    TicksPerQuarterNote(u16),
    TimeCode {
        frames_per_second: TimeCodeType,
        ticks_per_frame: u8,
    },
}
The division of a Standard Midi File, which specifies the meaning of the delta times in the file

Variants



TicksPerQuarterNote(u16)

Metrical time. Number of “ticks” per quarter note.



TimeCode

Time code based time.

Fields

frames_per_second: TimeCodeType
ticks_per_frame: u8

Implementations

Source

impl Division

pub fn beat_or_frame_to_tick(&self, beat_or_frame: f32) -> u32

Convert a beat or frame to the number of “ticks” in a file with this division.

pub fn ticks_to_beats_or_frames(&self, ticks: u32) -> f32

Convert a number of file “ticks” to a beat or frame in a file with this division.