ExtendedLoopType

Enum ExtendedLoopType 

pub enum ExtendedLoopType {
    Forward = 0,
    BiDirectional = 1,
    ForwardRelease = 2,
    BiDirectionalRelease = 3,
    Backward = 64,
    BackwardBiDirectional = 65,
    BackwardRelease = 66,
    BackwardBiDirectionalRelease = 67,
    BackwardOneShot = 126,
    OneShot = 127,
}
The type of loop being described by a SampleDumpMsg.

Variants



Forward = 0

A forward, unidirectional loop



BiDirectional = 1

Loop starts playing forward, gets to end and plays backward, repeating



ForwardRelease = 2

A unidirectional loop, upon key release the rest of the sample is played



BiDirectionalRelease = 3

A bidirectional loop, upon key release the rest of the sample is played



Backward = 64

A backward, unidirectional loop



BackwardBiDirectional = 65

Like BiDirectional, but starts playing in reverse



BackwardRelease = 66

A backward unidirectional loop, upon key release the rest of the sample after the loop is played backwards



BackwardBiDirectionalRelease = 67

A bidirectional loop, starting from the end playing backward, upon key release the rest of the sample after the loop is played backwards



BackwardOneShot = 126

Backwards one-shot, no looping



OneShot = 127

Forwards one-shot, no looping