SystemCommonMsg

Enum SystemCommonMsg 

pub enum SystemCommonMsg {
    TimeCodeQuarterFrame1(TimeCode),
    TimeCodeQuarterFrame2(TimeCode),
    TimeCodeQuarterFrame3(TimeCode),
    TimeCodeQuarterFrame4(TimeCode),
    TimeCodeQuarterFrame5(TimeCode),
    TimeCodeQuarterFrame6(TimeCode),
    TimeCodeQuarterFrame7(TimeCode),
    TimeCodeQuarterFrame8(TimeCode),
    SongPosition(u16),
    SongSelect(u8),
    TuneRequest,
}
A fairly limited set of messages, generally for device synchronization. Used in MidiMsg.

Variants



TimeCodeQuarterFrame1(TimeCode)

The first of 8 “quarter frame” messages, which are meant to be sent 4 per “frame”. These messages function similarly to SystemRealTimeMsg::TimingClock but additionally indicate the specific point in the playback that they refer to, as well as the frame rate. This means that a full TimeCode is send over the course of two frames.

They are sent in reverse order if time is playing in reverse.



TimeCodeQuarterFrame2(TimeCode)



TimeCodeQuarterFrame3(TimeCode)



TimeCodeQuarterFrame4(TimeCode)



TimeCodeQuarterFrame5(TimeCode)



TimeCodeQuarterFrame6(TimeCode)



TimeCodeQuarterFrame7(TimeCode)



TimeCodeQuarterFrame8(TimeCode)



SongPosition(u16)

Indicate the song position, in MIDI beats, where 1 MIDI beat = 6 MIDI clocks. 0-16383



SongSelect(u8)

Select a song numbered 0-127.



TuneRequest

Request that the oscillators of an analog synth be tuned.