GlobalParameterControl

Struct GlobalParameterControl 

pub struct GlobalParameterControl {
    pub slot_paths: Vec<SlotPath>,
    pub param_id_width: u8,
    pub value_width: u8,
    pub params: Vec<GlobalParameter>,
}
Global Parameter Control, to control parameters on a device that affect all sound. E.g. a global reverb. Used by UniversalRealTimeMsg::GlobalParameterControl.

As defined in CA-024.

This C/A is much more permissive than most, and thus has a pretty awkward interface.

Fields

slot_paths: Vec<SlotPath>

Between 0 and 127 SlotPaths, with each successive path representing a child of the preceding value. No paths refers to the “top level” (except if the first value refers to the top level ¯_(ツ)_/¯)

param_id_width: u8

The number of bytes present in the ids of params, must be greater than 0 Must line up with the values provided in params or output will be massaged

value_width: u8

The number of bytes present in the values of params, must be greater than 0 Must line up with the values provided in params` or output will be massaged

params: Vec<GlobalParameter>

Any number of GlobalParameters

Implementations

Source

impl GlobalParameterControl

pub fn reverb(reverb_type: Option<ReverbType>, reverb_time: Option<f32>) -> Self

Constructor for a GlobalParameterControl directed at a GM2 Reverb slot type.

reverb_time is the time in seconds (0.36 - 9.0) for which the low frequency portion of the original sound declines by 60dB

pub fn chorus( chorus_type: Option<ChorusType>, mod_rate: Option<f32>, mod_depth: Option<f32>, feedback: Option<f32>, send_to_reverb: Option<f32>, ) -> Self

Constructor for a GlobalParameterControl directed at a GM2 Chorus slot type.

mod_rate is the modulation frequency in Hz (0.0-15.5).

mod_depth is the peak-to-peak swing of the modulation in ms (0.3-40.0).

feedback is the amount of feedback from Chorus output in percent (0.0-97.0).

send_to_reverb is the send level from Chorus to Reverb in percent (0.0-100.0).