StandardTimeCode

Struct StandardTimeCode 

pub struct StandardTimeCode {
    pub subframes: SubFrames,
    pub frames: i8,
    pub seconds: u8,
    pub minutes: u8,
    pub hours: u8,
    pub code_type: TimeCodeType,
}
Like TimeCode but uses subframes to optionally include status flags, and fractional frames. Also may be negative. Used in MachineControlCommandMsg.

As defined in MIDI Machine Control 1.0 (MMA0016 / RP013) and MIDI Show Control 1.1.1 (RP002/RP014)

Fields

subframes: SubFramesframes: i8

The position in frames, where a negative value indicates a negative TimeCode, -29-29

seconds: u8

The position in seconds, 0-59

minutes: u8

The position in minutes, 0-59

hours: u8

The position in hours, 0-23

code_type: TimeCodeType

Implementations

Source

impl StandardTimeCode

pub fn to_bytes(self) -> [u8; 5]

Return the five byte representation of the frame: [fractional_frames, frames, seconds, minutes, timecode + hours]

pub fn to_bytes_short(self) -> [u8; 2]

The two byte representation of the frame: [fractional_frames, frames]